<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Khalid <khalid.aljahil@gmail.com>
 * @author Mostafa Hussein <mostafa@gmail.com>
 * @author Yaman Hokan <always.smile.yh@hotmail.com>
 * @author Usama Akkad <uahello@gmail.com>
 * @author Ahmad Abd-Elghany <tolpa1@gmail.com>
 * @author alhajr <alhajr300@gmail.com>
 * @author Mohamed Belhsine <b.mohamed897@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'rtl';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '؛';
$lang['btn_edit']              = 'حرر هذه الصفحة';
$lang['btn_source']            = 'اعرض مصدر الصفحة';
$lang['btn_show']              = 'اعرض الصفحة';
$lang['btn_create']            = 'أنشئ هذه الصفحة';
$lang['btn_search']            = 'ابحث';
$lang['btn_save']              = 'احفظ';
$lang['btn_preview']           = 'عاين';
$lang['btn_top']               = 'ارجع للأعلى';
$lang['btn_newer']             = '<< أحدث';
$lang['btn_older']             = 'أقدم >>';
$lang['btn_revs']              = 'نسخ قديمة';
$lang['btn_recent']            = 'أحدث التغييرات';
$lang['btn_upload']            = 'ارفع';
$lang['btn_cancel']            = 'ألغ';
$lang['btn_index']             = 'خريطة موقع';
$lang['btn_secedit']           = 'حرر';
$lang['btn_login']             = 'تسجيل الدخول';
$lang['btn_logout']            = 'خروج';
$lang['btn_admin']             = 'المدير';
$lang['btn_update']            = 'حدّث';
$lang['btn_delete']            = 'احذف';
$lang['btn_back']              = 'ارجع';
$lang['btn_backlink']          = 'ارتباطات';
$lang['btn_subscribe']         = 'ادر الاشتراكات';
$lang['btn_profile']           = 'حدث الملف الشخصي';
$lang['btn_reset']             = 'صفّر';
$lang['btn_resendpwd']         = 'اضبط كلمة سر جديدة';
$lang['btn_draft']             = 'حرر المسودة';
$lang['btn_recover']           = 'استرجع المسودة';
$lang['btn_draftdel']          = 'احذف المسوّدة';
$lang['btn_revert']            = 'استعد';
$lang['btn_register']          = 'سجّل';
$lang['btn_apply']             = 'طبق';
$lang['btn_media']             = 'مدير الوسائط';
$lang['btn_deleteuser']        = 'احذف حسابي الخاص';
$lang['btn_img_backto']        = 'عودة إلى %s';
$lang['btn_mediaManager']      = 'اعرض في مدير الوسائط';
$lang['loggedinas']            = 'داخل باسم:';
$lang['user']                  = 'اسم المستخدم';
$lang['pass']                  = 'كلمة السر';
$lang['newpass']               = 'كلمة سر جديدة';
$lang['oldpass']               = 'أكد كلمة السر الحالية';
$lang['passchk']               = 'مرة أخرى';
$lang['remember']              = 'تذكرني';
$lang['fullname']              = 'الاسم الحقيقي';
$lang['email']                 = 'البريد الإلكتروني';
$lang['profile']               = 'الملف الشخصي';
$lang['badlogin']              = 'عذرا، اسم المشترك أو كلمة السر غير صحيحة';
$lang['badpassconfirm']        = 'عذراً,كلمة السر غير صحيحة';
$lang['minoredit']             = 'تعديلات طفيفة';
$lang['draftdate']             = 'حفظ المسودات آليا مفعّل';
$lang['nosecedit']             = 'غُيرت الصفحة في هذه الأثناء، معلومات الجزء اصبحت قديمة. حُمُلت كل الصفحة بدلا.';
$lang['js']['search_toggle_tools'] = 'إظهار / إخفاء أدوات البحث';
$lang['js']['willexpire']      = 'سينتهي قفل تحرير هذه الصفحه خلال دقيقة.\nلتجنب التعارض استخدم زر المعاينة لتصفير مؤقت القفل.';
$lang['js']['notsavedyet']     = 'التعديلات غير المحفوظة ستفقد.';
$lang['js']['searchmedia']     = 'ابحث عن ملفات';
$lang['js']['keepopen']        = 'أبقي النافذة مفتوحة أثناء الاختيار';
$lang['js']['hidedetails']     = 'أخف التفاصيل';
$lang['js']['mediatitle']      = 'إعدادات الرابط';
$lang['js']['mediadisplay']    = 'نوع الرابط';
$lang['js']['mediaalign']      = 'المحاذاة';
$lang['js']['mediasize']       = 'حجم الصورة';
$lang['js']['mediatarget']     = 'هدف الرابط';
$lang['js']['mediaclose']      = 'أغلق';
$lang['js']['mediainsert']     = 'أدرج';
$lang['js']['mediadisplayimg'] = 'أظهر الصورة.';
$lang['js']['mediadisplaylnk'] = 'اظهر الرابط فقط.';
$lang['js']['mediasmall']      = 'نسخة مصغرة';
$lang['js']['mediamedium']     = 'نسخة متوسطة';
$lang['js']['medialarge']      = 'نسخة كبيرة';
$lang['js']['mediaoriginal']   = 'النسخة الأصلية';
$lang['js']['medialnk']        = 'الرابط لصفحة التفاصيل';
$lang['js']['mediadirect']     = 'رابط مباشر للأصل';
$lang['js']['medianolnk']      = 'لا رابط';
$lang['js']['medianolink']     = 'لا تربط الصورة';
$lang['js']['medialeft']       = 'حاذي الصورة إلى اليسار.';
$lang['js']['mediaright']      = 'حاذي الصورة إلى اليمين.';
$lang['js']['mediacenter']     = 'حاذي الصورة إلى الوسط.';
$lang['js']['medianoalign']    = 'لا تستعمل المحاذاة.';
$lang['js']['nosmblinks']      = 'الروابط لمجلدات مشاركة وندز تعمل فقط مع متصفح مايكروسفت Internet Explorer.
ما زال بإمكانك قص و لصق الرابط.';
$lang['js']['linkwiz']         = 'مرشد الروابط';
$lang['js']['linkto']          = 'الرابط إلى :';
$lang['js']['del_confirm']     = 'هل حقاً تريد حذف البنود المختارة؟';
$lang['js']['restore_confirm'] = 'أمتأكد من استرجاع هذه النسخة؟';
$lang['js']['media_diff']      = 'عرض الفروق:';
$lang['js']['media_diff_both'] = 'جنبا إلى جنب';
$lang['js']['media_diff_portions'] = 'اسحب';
$lang['js']['media_select']    = 'اختر ملفا...';
$lang['js']['media_upload_btn'] = 'ارفع';
$lang['js']['media_done_btn']  = 'تم';
$lang['js']['media_drop']      = 'اسقط الملف هنا لرفعه';
$lang['js']['media_cancel']    = 'أزل';
$lang['js']['media_overwrt']   = 'أكتب فوق الملفات الموجودة';
$lang['search_exact_match']    = 'تطابق تام';
$lang['search_starts_with']    = 'يبدأ بالتالي';
$lang['search_ends_with']      = 'ينتهي بالتالي';
$lang['search_contains']       = 'يحتوي';
$lang['search_custom_match']   = 'مخصص';
$lang['search_any_time']       = 'أي وقت';
$lang['search_past_7_days']    = 'الأسبوع الماضي';
$lang['search_past_month']     = 'الشهر الماضي';
$lang['search_past_year']      = 'السنة الماضية';
$lang['search_sort_by_hits']   = 'فرز حسب عدد الزيارات';
$lang['search_sort_by_mtime']  = 'فرز حسب وقت آخر تعديل';
$lang['regmissing']            = 'عذرا، عليك ملء جميع الحقول.';
$lang['reguexists']            = 'عذرا، يوجد مشترك بنفس الاسم.';
$lang['regsuccess']            = 'أنشئ المستخدم و ارسلت كلمة السر بالبريد.';
$lang['regsuccess2']           = 'أنشئ المستخدم.';
$lang['regfail']               = 'لا يمكن إنشاء المستخدم.';
$lang['regmailfail']           = 'حدث خطأ فى إرسال رسالة كلمة السر. يرجى مراسلة المدير!';
$lang['regbadmail']            = 'يبدو البريد الإلكتروني المعطى غيرَ صحيح، إن كنت تظن أن هذا خطأ، راسل المدير';
$lang['regbadpass']            = 'كلمتا المرور غير متطابقتين، حاول مرة أخرى.';
$lang['regpwmail']             = 'كلمة مرورك إلى دوكو ويكي';
$lang['reghere']               = 'ليس لديك حساب بعد؟ احصل على واحد';
$lang['profna']                = 'هذه الويكي لا تدعم تعديل الملف الشخصي';
$lang['profnochange']          = 'لا تغييرات، لا شيء ليُعمل.';
$lang['profnoempty']           = 'غير مسموح باسم مستخدم أو بريد فارغ.';
$lang['profchanged']           = 'حُدث الملف الشخصي للمستخدم بنجاح.';
$lang['profnodelete']          = 'هذه الموسوعه لا ندعم حذف الأشخاص';
$lang['profdeleteuser']        = 'احذف حساب';
$lang['profdeleted']           = 'حسابك الخاص تم حذفه من هذه الموسوعة';
$lang['profconfdelete']        = 'أنا أرغب في حذف حسابي من هذه الموسوعة.<br/>
هذا الحدث غير ممكن.';
$lang['profconfdeletemissing'] = 'لم تقم بوضع علامة في مربع التأكيد';
$lang['proffail']              = 'لم يتم تحديث ملف المستخدم';
$lang['pwdforget']             = 'أنسيت كلمة السر؟ احصل على واحدة جديدة';
$lang['resendna']              = 'هذه الويكي لا تدعم إعادة إرسال كلمة المرور.';
$lang['resendpwd']             = 'اضبط كلمة سر جديدة لـ';
$lang['resendpwdmissing']      = 'عذراّ، يجب أن تملأ كل الحقول.';
$lang['resendpwdnouser']       = 'عذراً، لم نجد المستخدم هذا في قاعدة بياناتنا.';
$lang['resendpwdbadauth']      = 'عذراً، رمز التفعيل هذا غير صحيح. نأكد من استخدامك كامل وصلة التأكيد.';
$lang['resendpwdconfirm']      = 'اُرسل رابط التأكيد بواسطة البريد.';
$lang['resendpwdsuccess']      = 'كلمة السرالجديدة اُرسلت عبر البريد.';
$lang['license']               = 'مالم يشر لخلاف ذلك، فإن المحتوى في هذه الويكي مرخص وفق الرخصة التالية:';
$lang['licenseok']             = 'لاحظ: بتحرير هذه الصفحة أنت توافق على ترخيص محتواها تحت الرخصة التالية:';
$lang['searchmedia']           = 'ابحث في أسماء الملفات:';
$lang['searchmedia_in']        = 'ابحث في %s';
$lang['txt_upload']            = 'اختر ملفاً للرفع:';
$lang['txt_filename']          = 'رفع كـ (اختياري):';
$lang['txt_overwrt']           = 'اكتب على ملف موجود';
$lang['maxuploadsize']         = 'الحجم الاقصى %s للملف';
$lang['lockedby']              = 'مقفلة حاليا لـ:';
$lang['lockexpire']            = 'ينتهي القفل في:';
$lang['rssfailed']             = 'خطأ ما حدث أثناء جلب ملف التغذية:';
$lang['nothingfound']          = 'لا يوجد شيء';
$lang['mediaselect']           = 'ملفات الوسائط';
$lang['uploadsucc']            = 'تم الرفع بنجاح';
$lang['uploadfail']            = 'فشل الرفع، ربما خطأ تراخيص؟';
$lang['uploadwrong']           = 'الرفع ممنوع، نوع الملف مرفوض!';
$lang['uploadexist']           = 'الملف موجود أصلاً. لم يُعمل شيئ.';
$lang['uploadbadcontent']      = 'المحتوى المرفوع لم يطابق لاحقة ملفات %s.';
$lang['uploadspam']            = 'الرفع محجوب بواسطة القائمة السوداء لبرنامج تقفي التطفل.';
$lang['uploadxss']             = 'رُفض الرفع للإشتباه بمحتوى ضار.';
$lang['uploadsize']            = 'الملف المرفوع كان كبيرا جدا . ( الحد %s )';
$lang['deletesucc']            = 'حُذف الملف "%s".';
$lang['deletefail']            = 'تعذر حذف "%s" - تأكد من الصلاحيات.';
$lang['mediainuse']            = 'لم يحذف الملف "%s" - مازال مستخدما.';
$lang['namespaces']            = 'فضاء التسمية';
$lang['mediafiles']            = 'ملفات موجودة في';
$lang['accessdenied']          = 'لا يسمح لك برؤية هذه الصفحة.';
$lang['mediausage']            = 'استخدم هذه الصياغة للدلالة على هذا الملف:';
$lang['mediaview']             = 'اعرض الملف الأصلي';
$lang['mediaroot']             = 'الجذر';
$lang['mediaupload']           = 'تحميل ملف إلى فضاء التسمية هنا. لإنشاء فضاءات تسمية فرعية، أضفها إلى بداية خانة تحميل باسم وافصل بينها باستخدام الفاصلتان الرأسيتان.';
$lang['mediaextchange']        = 'غُيرت لاحقة الملف من .%s إلى .%s!';
$lang['reference']             = 'مراجع لـ';
$lang['ref_inuse']             = 'لا يمكن حذف الملف، لأنه مستخدم من قبل الصفحات التالية:';
$lang['ref_hidden']            = 'بعض المراجع على صفحات لا تملك صلاحيات قراءتها';
$lang['hits']                  = 'مرة';
$lang['quickhits']             = 'صفحات مطابقة';
$lang['toc']                   = 'جدول المحتويات';
$lang['current']               = 'حالي';
$lang['yours']                 = 'نسختك';
$lang['diff']                  = 'أظهر الاختلافات مع النسخة الحالية';
$lang['diff2']                 = 'أظهر الاختلافات بين النسخ المحددة';
$lang['difflink']              = 'رابط إلى هذه المقارنة';
$lang['diff_type']             = 'أظهر الفروق:';
$lang['diff_inline']           = 'ضمنا';
$lang['diff_side']             = 'جنبا إلى جنب';
$lang['diffprevrev']           = 'المراجعة السابقة';
$lang['diffnextrev']           = 'المراجعة التالية';
$lang['difflastrev']           = 'المراجعة الأخيرة';
$lang['diffbothprevrev']       = 'جانبي المراجعة السابقة';
$lang['diffbothnextrev']       = 'جانبي المراجعة التالية';
$lang['line']                  = 'سطر';
$lang['breadcrumb']            = 'أثر:';
$lang['youarehere']            = 'أنت هنا:';
$lang['lastmod']               = 'آخر تعديل:';
$lang['by']                    = 'بواسطة';
$lang['deleted']               = 'حذفت';
$lang['created']               = 'اُنشئت';
$lang['restored']              = 'استعيدت نسخة قديمة (%s)';
$lang['external_edit']         = 'تحرير خارجي';
$lang['summary']               = 'ملخص التحرير';
$lang['noflash']               = 'تحتاج إلى<a href="http://get.adobe.com/flashplayer">ملحق فلاش أدوبي</a> لعرض هذا المحتوى.';
$lang['download']              = 'نزل Snippet';
$lang['tools']                 = 'أدوات';
$lang['user_tools']            = 'أدوات المستخدم';
$lang['site_tools']            = 'أدوات الموقع';
$lang['page_tools']            = 'أدوات الصفحة';
$lang['skip_to_content']       = 'تجاوز إلى المحتوى';
$lang['sidebar']               = 'العمود الجانبي';
$lang['mail_newpage']          = 'إضافة صفحة:';
$lang['mail_changed']          = 'تعديل صفحة:';
$lang['mail_subscribe_list']   = 'صفحات غيرت في النطاق:';
$lang['mail_new_user']         = 'مشترك جديد:';
$lang['mail_upload']           = 'رفع ملف:';
$lang['changes_type']          = 'أظهر تغييرات الـ';
$lang['pages_changes']         = 'صفحات';
$lang['media_changes']         = 'ملفات الوسائط';
$lang['both_changes']          = 'كلا من الصفحات وملفات الوسائط';
$lang['qb_bold']               = 'نص عريض';
$lang['qb_italic']             = 'نص مائل';
$lang['qb_underl']             = 'نص مسطر';
$lang['qb_code']               = 'نص برمجي';
$lang['qb_strike']             = 'نص مشطوب';
$lang['qb_h1']                 = 'عنوان مستوى ١';
$lang['qb_h2']                 = 'عنوان مستوى ٢';
$lang['qb_h3']                 = 'عنوان مستوى ٣';
$lang['qb_h4']                 = 'عنوان مستوى ٤';
$lang['qb_h5']                 = 'عنوان مستوى ٥';
$lang['qb_h']                  = 'الترويسة';
$lang['qb_hs']                 = 'حدد الترويسة';
$lang['qb_hplus']              = 'ترويسة أعلى';
$lang['qb_hminus']             = 'ترويسة أخفض';
$lang['qb_hequal']             = 'ترويسة بنفس المستوى';
$lang['qb_link']               = 'رابط داخلي';
$lang['qb_extlink']            = 'رابط خارجي';
$lang['qb_hr']                 = 'سطر أفقي';
$lang['qb_ol']                 = 'بند فى قائمة مرتبة';
$lang['qb_ul']                 = 'بند فى قائمة غير مرتبة';
$lang['qb_media']              = 'أضف صورا و ملفات أخرى';
$lang['qb_sig']                = 'أدرج التوقيع';
$lang['qb_smileys']            = 'الإبتسامات';
$lang['qb_chars']              = 'محارف خاصة';
$lang['upperns']               = 'انتقل للنطاق الأب';
$lang['metaedit']              = 'تحرير البيانات الشمولية ';
$lang['metasaveerr']           = 'فشلت كتابة البيانات الشمولية';
$lang['metasaveok']            = 'حُفظت البيانات الشمولية';
$lang['img_title']             = 'العنوان:';
$lang['img_caption']           = 'وصف:';
$lang['img_date']              = 'التاريخ:';
$lang['img_fname']             = 'اسم الملف:';
$lang['img_fsize']             = 'الحجم:';
$lang['img_artist']            = 'المصور:';
$lang['img_copyr']             = 'حقوق النسخ:';
$lang['img_format']            = 'الهيئة:';
$lang['img_camera']            = 'الكمرا:';
$lang['img_keywords']          = 'كلمات مفتاحية:';
$lang['img_width']             = 'العرض:';
$lang['img_height']            = 'الإرتفاع:';
$lang['subscr_subscribe_success'] = 'اضيف %s لقائمة اشتراك %s';
$lang['subscr_subscribe_error'] = 'خطأ في إضافة %s لقائمة اشتراك %s';
$lang['subscr_subscribe_noaddress'] = 'ليس هناك عنوان مرتبط بولوجك، لا يمكن اضافتك لقائمة الاشتراك';
$lang['subscr_unsubscribe_success'] = 'أزيل %s من قائمة اشتراك %s';
$lang['subscr_unsubscribe_error'] = 'خطأ في إزالة %s من قائمة اشتراك %s';
$lang['subscr_already_subscribed'] = '%s مشترك مسبقا في %s';
$lang['subscr_not_subscribed'] = '%s ليس مشتركا في %s';
$lang['subscr_m_not_subscribed'] = 'لست مشتركا حاليا بالصفحة او النطاق الحاليين';
$lang['subscr_m_new_header']   = 'أضف اشتراكا';
$lang['subscr_m_current_header'] = 'الاشتراكات الحالية';
$lang['subscr_m_unsubscribe']  = 'ألغ الاشتراك';
$lang['subscr_m_subscribe']    = 'اشترك';
$lang['subscr_m_receive']      = 'استقبال';
$lang['subscr_style_every']    = 'بريدا على كل تغيير';
$lang['subscr_style_digest']   = 'البريد الإلكتروني, ملخص للتغييرات لكل صفحة (كل يوم %.2f)';
$lang['subscr_style_list']     = 'قائمة بالصفحات التي تم تغييرها منذ آخر بريد الإلكتروني (كل يوم %.2f)';
$lang['authtempfail']          = 'تصريح المشترك غير متوفر مؤقتاً، إن استمرت هذه الحالة يرجى مراسلة المدير';
$lang['i_chooselang']          = 'اختر لغتك';
$lang['i_installer']           = 'برنامج تنصيب دوكو ويكي';
$lang['i_wikiname']            = 'اسم الويكي';
$lang['i_enableacl']           = 'تفعيل ACL - مفضل';
$lang['i_superuser']           = 'مشرف';
$lang['i_problems']            = 'وجد برنامج التنصيب المشاكل التالية، لا يمكنك المتابعة قبل حلها.';
$lang['i_modified']            = 'لأسباب أمنية هذا البرنامج سيعمل فقط مع تنصيب دوكو ويكي جديد و غير معدّل.
يجب أن تعيد فك ضغط الملفات مرة أخرى من المكتبة المضغوطة، أو راجع <a href="https://www.dokuwiki.org/install"> تعليمات تنصيب دوكو ويكي </a> ';
$lang['i_funcna']              = 'دالة PHP التالية غير متوفرة.
<code>%s</code>
قد يكون مزود خدمة الاستفادة قد حجبها لسبب ما.';
$lang['i_phpver']              = 'نسخة PHP التي لديك هي
<code>%s</code>
وهي أقل من النسخة المطلوبة
<code>%s</code>
عليك تحديث نسخة PHP';
$lang['i_mbfuncoverload']      = 'يجب ايقاف تشغيل mbstring.func_overload في ملف php.ini لتشغيل دوكوويكي.';
$lang['i_permfail']            = 'إن <code>%s</code> غير قابل للكتابة بواسطة دوكو ويكي، عليك تعديل إعدادات الصلاحيات لهذا المجلد!';
$lang['i_confexists']          = 'إن <code>%s</code> موجود أصلاً';
$lang['i_writeerr']            = 'لا يمكن إنشاء <code>%s</code>، عليك التأكد من صلاحيات الملف أو المجلد وإنشاء الملف يدوياً.';
$lang['i_badhash']             = 'الملف dokuwiki.php غير مصنف أو قد تم تعديله
(hash=<code>%s</code>)';
$lang['i_badval']              = 'القيمة <code>%s</code> غير شرعية أو فارغة';
$lang['i_success']             = 'الإعدادات تمت بنجاح، يرجى حذف الملف install.php الآن.
ثم تابع إلى <a href="doku.php?id=wiki:welcome"> دوكو ويكي الجديدة</a>';
$lang['i_failure']             = 'بعض الأخطاء حدثت أثنا كتابة ملفات الإعدادات، عليك تعديلها يدوياً قبل أن تستطيع استخدام <a href="doku.php?id=wiki:welcome"> دوكو ويكي الجديدة</a>';
$lang['i_policy']              = 'تصريح ACL مبدئي';
$lang['i_pol0']                = 'ويكي مفتوحة؛ أي القراءة والكتابة والتحميل مسموحة للجميع';
$lang['i_pol1']                = 'ويكي عامة؛ أي القراءة للجميع ولكن الكتابة والتحميل للمشتركين المسجلين فقط';
$lang['i_pol2']                = 'ويكي مغلقة؛ أي القراءة والكتابة والتحميل للمشتركين المسجلين فقط';
$lang['i_allowreg']            = 'السماح للمستخدمين بتسجيل أنفسهم';
$lang['i_retry']               = 'إعادة المحاولة';
$lang['i_license']             = 'اختر الرخصة التي تريد وضع المحتوى تحتها:';
$lang['i_license_none']        = 'لا تظهر أية معلومات للترخيص';
$lang['i_pop_field']           = 'من فضلك، ساعدنا على تحسين تجربة دوكي ويكي:';
$lang['i_pop_label']           = 'مرة واحدة في شهر، إرسال بيانات استخدام المجهول للمطورين دوكي ويكي';
$lang['recent_global']         = 'انت تراقب حاليا التغييرات داخل نطاق <b>%s</b>. يمكنك أيضا <a href="%s">عرض أحدث تغييرات الويكي كلها</a>.';
$lang['years']                 = '%d سنة مضت';
$lang['months']                = '%d شهرا مضى';
$lang['weeks']                 = '%d اسبوعا مضى';
$lang['days']                  = '%d يوما مضى';
$lang['hours']                 = '%d ساعة مضت';
$lang['minutes']               = '%d دقيقة مضت';
$lang['seconds']               = '%d ثانية مضت';
$lang['wordblock']             = 'لم تحفظ تغييراتك لاحتوائها على نص ممنوع )غثاء(';
$lang['media_uploadtab']       = 'ارفع';
$lang['media_searchtab']       = 'ابحث';
$lang['media_file']            = 'ملف';
$lang['media_viewtab']         = 'عرض';
$lang['media_edittab']         = 'تحرير';
$lang['media_historytab']      = 'التاريخ';
$lang['media_list_thumbs']     = 'المصغرات';
$lang['media_list_rows']       = 'صفوف';
$lang['media_sort_name']       = 'الاسم';
$lang['media_sort_date']       = 'التاريخ';
$lang['media_namespaces']      = 'اختر نطاقا';
$lang['media_files']           = 'الملفات في %s';
$lang['media_upload']          = 'ارفع إلى %s';
$lang['media_search']          = 'ابحث في %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s في %s';
$lang['media_edit']            = 'حرر %s';
$lang['media_history']         = 'تاريخ %s';
$lang['media_meta_edited']     = 'عُدلت الميتاداتا';
$lang['media_perm_read']       = 'عفوا، لست مخولا بقراءة الملفات.';
$lang['media_perm_upload']     = 'عفوا، لست مخولا برفع الملفات.';
$lang['media_update']          = 'ارفع إصدارا أحدث';
$lang['media_restore']         = 'استرجع هذه النسخة';
$lang['currentns']             = 'مساحة الاسم الحالية';
$lang['searchresult']          = 'نتيجة البحث';
$lang['plainhtml']             = 'نص HTML غير منسق';
$lang['wikimarkup']            = 'علامات الوكي';
$lang['email_signature_text']  = 'أنشئت هذه الرسالة من دوكو ويكي في
@DOKUWIKIURL@';
